@@ -178,9 +178,9 @@ class Range(Generic[TOrd]):
             return self.lowerbound < value <= self.upperbound
 
     @property
-    def bound(self):
+    def bound(self) -> bool:
         """True if neither boundary is unbounded."""
-        return self._lower and self._upper
+        return bool(self._lower) and bool(self._upper)
 
     def diff(self, other: "Range") -> Tuple["Range", ...]:
         """The difference of self from other.
